==> lyrics_naver-0.0.3.amarokscript.tar.gz: lyrics_naver/amarok_naver.rb <==
# Core lyric_naver
# This file fetches html document from naver and parse it.
#
# ChangeLog:
# 07 Feb 2007: Fixed bug when fetched html does not have 
#     canonical title and artist. (by Yeom Jaehyun)
# 07 Feb 2007: Deleted getLyricHTML def.
# 07 Feb 2007: Separated MyWeb module.
# 07 Feb 2007: Changed file name to amarok_naver and
#     module name to AmarokNaver.
#
require 'my_web'
require 'cgi'
require 'iconv'

module AmarokNaver
  # Convert query string from utf-8 to euc-kr which is naver's encoding
  def AmarokNaver.getQueryString(query)
    CGI.escape(Iconv.new('euc-kr', 'utf-8').iconv(CGI.unescape(query).delete('.')))
  end

  # Parse song id from fetched html
  def AmarokNaver.getSongId(query)
    queryStr = getQueryString(query)
    url = "http://music.naver.com/search.nhn?where=lyric&query=#{queryStr}"
    body = MyWeb.fetchFromHttp(url)
    scanned = body.scan(/javascript\:lyric\(\'([0-9]*)\'\)/)[0]
    scanned == nil ? nil : scanned[0]
  end

  # parse lyric from fetched html
  def AmarokNaver.parseLyric(body)
    scanned = body.scan(/>([^-]*) - <b>([^<]*)<\/b>/)
    title, artist = ["", ""]
    if scanned != nil && scanned[0] != nil then
      title = Iconv.new('utf-8', 'euc-kr').iconv(scanned[0][0])
      artist = Iconv.new('utf-8', 'euc-kr').iconv(scanned[0][1])
    end
    lyric = Iconv.new('utf-8', 'euc-kr').iconv(body.scan(/<textarea[^>]*>([^<]*)<\/textarea>/)[0][0])
    return title, artist, lyric
  end

  # Get lyric from specified url
  def AmarokNaver.getLyricFromUrl(url)
    body = MyWeb.fetchFromHttp(url)
    body != nil ? parseLyric(body) : [nil, nil, nil]
  end

  # Get lyric from query and songId is gotten if it is nil
  def AmarokNaver.getLyric(query, songId=nil)
    queryStr = getQueryString(query)
    songId = getSongId(query) if songId == nil
    return "" if songId == nil
    url = "http://music.naver.com/search.nhn?where=lyric&popup=lyric&songid=#{songId}&query=#{queryStr}"
    getLyricFromUrl(url)
  end
end

==> lyrics_naver-0.1.0.amarokscript.tar.gz: lyrics_naver/amarok_naver.rb <==
# Core lyric_naver
# This file fetches html document from naver and parse it.
#
# ChangeLog:
# 07 Feb 2007: Fixed bug when fetched html does not have 
#     canonical title and artist. (by Yeom Jaehyun)
# 07 Feb 2007: Deleted getLyricHTML def.
# 07 Feb 2007: Separated MyWeb module.
# 07 Feb 2007: Changed file name to amarok_naver and
#     module name to AmarokNaver.
# 26 Mar 2007: Added support for euc-kr.
#
require 'my_web'
require 'cgi'
require 'iconv'

module AmarokNaver
  # Convert query string from utf-8 to euc-kr which is naver's encoding
  def AmarokNaver.getQueryString(query)
    CGI.escape(MyWeb.encodeToEucKr(CGI.unescape(query).delete('.')))
  rescue Iconv::IllegalSequence
    return CGI.escape(CGI.unescape(query))
  end

  # Parse song id from fetched html
  def AmarokNaver.getSongId(query)
    queryStr = getQueryString(query)
    url = "http://music.naver.com/search.nhn?where=lyric&query=#{queryStr}"
    body = MyWeb.fetchFromHttp(url)
    scanned = body.scan(/javascript\:lyric\(\'([0-9]*)\'\)/)[0]
    scanned == nil ? nil : scanned[0]
  end

  # parse lyric from fetched html
  def AmarokNaver.parseLyric(body)
    scanned = body.scan(/>([^-]*) - <b>([^<]*)<\/b>/)
    title, artist = ["", ""]
    lyric = body.match(/<textarea[^>]*>([^<]*)<\/textarea>/)
    lyric = (lyric != nil ? lyric.captures[0] : nil)
    lyric = MyWeb.encodeToUTF8(lyric)
    if scanned != nil && scanned[0] != nil then
      title = MyWeb.encodeToUTF8(scanned[0][0])
      artist = MyWeb.encodeToUTF8(scanned[0][1])
    end
    return title, artist, lyric
  rescue Iconv::IllegalSequence
    return title, artist, lyric
  end

  # Get lyric from specified url
  def AmarokNaver.getLyricFromUrl(url)
    body = MyWeb.fetchFromHttp(url)
    body != nil ? parseLyric(body) : [nil, nil, nil]
  end

  # Get lyric from query and songId is gotten if it is nil
  def AmarokNaver.getLyric(query, songId=nil)
    queryStr = getQueryString(query)
    songId = getSongId(query) if songId == nil
    return "" if songId == nil
    url = "http://music.naver.com/search.nhn?where=lyric&popup=lyric&songid=#{songId}&query=#{queryStr}"
    getLyricFromUrl(url)
  end
end
